DMconv <-
structure(list(id = as.integer(c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 
27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 
43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 
59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 
75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 
91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 
105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 
118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 
131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 
144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 
157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 
170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 
183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 
196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 
209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 
222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 
235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 
248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 
261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272, 273, 
274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 
287, 288, 289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 
300, 301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312, 
313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324, 325, 
326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 
339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 
352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 
365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 
378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 
391, 392, 393, 394, 395, 396, 397, 398, 399, 400, 401, 402, 403, 
404, 405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 
417, 418, 419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 
430, 431, 432, 433, 434, 435, 436, 437, 438, 439, 440, 441, 442, 
443, 444, 445, 446, 447, 448, 449, 450, 451, 452, 453, 454, 455, 
456, 457, 458, 459, 460, 461, 462, 463, 464, 465, 466, 467, 468, 
469, 470, 471, 472, 473, 474, 475, 476, 477, 478, 479, 480, 481, 
482, 483, 484, 485, 486, 487, 488, 489, 490, 491, 492, 493, 494, 
495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 506, 507, 
508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520, 
521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532, 533, 
534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 544, 545, 546, 
547, 548, 549, 550, 551, 552, 553, 554, 555, 556, 557, 558, 559, 
560, 561, 562, 563, 564, 565, 566, 567, 568, 569, 570, 571, 572, 
573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 
586, 587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 
599, 600, 601, 602, 603, 604, 605, 606, 607, 608, 609, 610, 611, 
612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 622, 623, 624, 
625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 635, 636, 637, 
638, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 
651, 652, 653, 654, 655, 656, 657, 658, 659, 660, 661, 662, 663, 
664, 665, 666, 667, 668, 669, 670, 671, 672, 673, 674, 675, 676, 
677, 678, 679, 680, 681, 682, 683, 684, 685, 686, 687, 688, 689, 
690, 691, 692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 
703, 704, 705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 
716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 741, 
742, 743, 744, 745, 746, 747, 748, 749, 750, 751, 752, 753, 754, 
755, 756, 757, 758, 759, 760, 761, 762, 763, 764, 765, 766, 767, 
768, 769, 770, 771, 772, 773, 774, 775, 776, 777, 778, 779, 780, 
781, 782, 783, 784, 785, 786, 787, 788, 789, 790, 791, 792, 793, 
794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 
807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 
820, 821, 822, 823, 824, 825, 826, 827, 828, 829, 830, 831, 832, 
833, 834, 835, 836, 837, 838, 839, 840, 841, 842, 843, 844, 845, 
846, 847, 848, 849, 850, 851, 852, 853, 854, 855, 856, 857, 858, 
859, 860, 861, 862, 863, 864, 865, 866, 867, 868, 869, 870, 871, 
872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
898, 899, 900, 901, 902, 903, 904, 905, 906, 907, 908, 909, 910, 
911, 912, 913, 914, 915, 916, 917, 918, 919, 920, 921, 922, 923, 
924, 925, 926, 927, 928, 929, 930, 931, 932, 933, 934, 935, 936, 
937, 938, 939, 940, 941, 942, 943, 944, 945, 946, 947, 948, 949, 
950, 951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 
963, 964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 
976, 977, 978, 979, 980, 981, 982, 983, 984, 985, 986, 987, 988, 
989, 990, 991, 992, 993, 994, 995, 996, 997, 998, 999, 1000, 
1001, 1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011, 
1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020, 1021, 1022, 
1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030, 1031, 1032, 1033, 
1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044, 
1045, 1046, 1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055, 
1056, 1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 1066, 
1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075, 1076, 1077, 
1078, 1079, 1080, 1081, 1082, 1083, 1084, 1085, 1086, 1087, 1088, 
1089, 1090, 1091, 1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099, 
1100, 1101, 1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110, 
1111, 1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121, 
1122, 1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1132, 
1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143, 
1144, 1145, 1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 
1155, 1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165, 
1166, 1167, 1168, 1169, 1170, 1171, 1172, 1173, 1174, 1175, 1176, 
1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184, 1185, 1186, 1187, 
1188, 1189, 1190, 1191, 1192, 1193, 1194, 1195, 1196, 1197, 1198, 
1199, 1200, 1201, 1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209, 
1210, 1211, 1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220, 
1221, 1222, 1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231, 
1232, 1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241, 1242, 
1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251, 1252, 1253, 
1254, 1255, 1256, 1257, 1258, 1259, 1260, 1261, 1262, 1263, 1264, 
1265, 1266, 1267, 1268, 1269, 1270, 1271, 1272, 1273, 1274, 1275, 
1276, 1277, 1278, 1279, 1280, 1281, 1282, 1283, 1284, 1285, 1286, 
1287, 1288, 1289, 1290, 1291, 1292, 1293, 1294, 1295, 1296, 1297, 
1298, 1299, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 
1309, 1310, 1311, 1312, 1313, 1314, 1315, 1316, 1317, 1318, 1319, 
1320, 1321, 1322, 1323, 1324, 1325, 1326, 1327, 1328, 1329, 1330, 
1331, 1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339, 1340, 1341, 
1342, 1343, 1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351, 1352, 
1353, 1354, 1355, 1356, 1357, 1358, 1359, 1360, 1361, 1362, 1363, 
1364, 1365, 1366, 1367, 1368, 1369, 1370, 1371, 1372, 1373, 1374, 
1375, 1376, 1377, 1378, 1379, 1380, 1381, 1382, 1383, 1384, 1385, 
1386, 1387, 1388, 1389, 1390, 1391, 1392, 1393, 1394, 1395, 1396, 
1397, 1398, 1399, 1400, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 
1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 
1419, 1420, 1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 
1430, 1431, 1432, 1433, 1434, 1435, 1436, 1437, 1438, 1439, 1440, 
1441, 1442, 1443, 1444, 1445, 1446, 1447, 1448, 1449, 1450, 1451, 
1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461, 1462, 
1463, 1464, 1465, 1466, 1467, 1468, 1469, 1470, 1471, 1472, 1473, 
1474, 1475, 1476, 1477, 1478, 1479, 1480, 1481, 1482, 1483, 1484, 
1485, 1486, 1487, 1488, 1489, 1490, 1491, 1492, 1493, 1494, 1495, 
1496, 1497, 1498, 1499, 1500, 1501, 1502, 1503, 1504, 1505, 1506, 
1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1515, 1516, 1517, 
1518, 1519)), doe = structure(c(12215, 11866, 11568, 11841, 11288, 
11565, 11584, 11506, 11542, 11699, 11549, 11589, 11442, 11310, 
11504, 11588, 12071, 11608, 12019, 11910, 11897, 11397, 11432, 
11630, 11993, 12127, 11488, 12064, 11599, 11419, 12023, 11387, 
11627, 11533, 11623, 11579, 11407, 11576, 11611, 11524, 11624, 
11575, 11887, 11416, 11553, 12155, 11520, 11569, 11641, 11572, 
12160, 12242, 11587, 11539, 11583, 11406, 11737, 11399, 11571, 
11854, 11724, 11481, 11999, 12104, 11638, 11469, 11705, 11441, 
12024, 11407, 11587, 11584, 12161, 11600, 11588, 11637, 11429, 
11616, 12153, 11690, 11530, 11950, 11613, 11766, 11729, 11477, 
11679, 11505, 11295, 11470, 11606, 11741, 11636, 11590, 11757, 
11731, 11469, 11693, 11625, 11603, 11603, 12196, 11954, 11656, 
11528, 11375, 11475, 11514, 11632, 11977, 12191, 12314, 12073, 
12132, 11774, 12003, 11972, 11842, 11936, 12335, 11811, 11896, 
12095, 11988, 11880, 11800, 11918, 11942, 11780, 11771, 11861, 
12091, 11983, 12180, 11991, 11950, 12214, 12064, 11965, 11952, 
11876, 12122, 12160, 11911, 12381, 12115, 11881, 12705, 12074, 
12081, 11726, 11791, 12078, 12023, 12229, 12058, 11996, 11779, 
12102, 11996, 12055, 12412, 12148, 12005, 11952, 11841, 12861, 
12132, 11764, 12048, 11979, 12116, 11945, 12060, 12306, 12182, 
12326, 12141, 12124, 11957, 11964, 11740, 12166, 11890, 11989, 
12069, 11951, 12166, 12067, 12069, 11891, 12642, 12460, 11866, 
11954, 11937, 12202, 12125, 12178, 12092, 11782, 12047, 12316, 
12225, 12095, 12081, 12065, 11954, 11965, 11842, 12296, 11936, 
12174, 12076, 11766, 12009, 12423, 11887, 11869, 11742, 11815, 
12041, 11759, 12325, 11862, 11744, 11832, 11832, 11705, 11703, 
11916, 12527, 11715, 11952, 11707, 11907, 12035, 11860, 12032, 
11817, 12001, 11793, 12095, 11980, 12175, 11850, 11845, 12068, 
11931, 11638, 11989, 11741, 11996, 12001, 11998, 11839, 12189, 
12122, 11698, 12092, 12330, 12056, 11869, 11878, 11880, 12319, 
11771, 11760, 12463, 11639, 11719, 11933, 11862, 11688, 11925, 
12867, 11653, 12007, 11657, 11990, 11907, 12149, 11952, 11883, 
12160, 11792, 11907, 11643, 11842, 11662, 11502, 11620, 12003, 
11610, 12361, 12094, 11579, 11673, 12298, 11862, 11598, 11668, 
11630, 12028, 11724, 11713, 12818, 12164, 11828, 11846, 11815, 
11877, 11855, 11612, 12327, 11963, 11818, 11926, 12173, 12185, 
11737, 11982, 12325, 12012, 11742, 11754, 11880, 11912, 11987, 
11825, 11628, 11837, 11999, 11557, 11833, 12056, 11741, 11990, 
11500, 11863, 11502, 11843, 11839, 11683, 11599, 12236, 12042, 
12259, 12288, 11997, 11773, 11816, 12116, 11699, 11836, 11944, 
11828, 11670, 12280, 11570, 11545, 11941, 11606, 11840, 11685, 
11822, 11673, 12356, 11459, 11887, 11489, 11965, 12249, 11736, 
11500, 12070, 11580, 11561, 11570, 11711, 11715, 11753, 11984, 
11946, 12224, 11794, 12015, 12125, 11843, 11867, 11821, 11789, 
12082, 12048, 11952, 12180, 11821, 12001, 11755, 11825, 11800, 
12207, 12187, 11962, 11949, 11831, 11781, 11981, 11657, 11878, 
12168, 11653, 11903, 11784, 12051, 12074, 11749, 11788, 11914, 
12348, 11926, 11744, 11799, 11870, 11966, 12000, 11778, 11713, 
11793, 11661, 11770, 12472, 11825, 11646, 11955, 11818, 11806, 
12138, 11804, 11906, 11702, 12017, 12432, 11741, 11480, 11897, 
11686, 11603, 11822, 11443, 11613, 11661, 11866, 12108, 11656, 
11720, 12178, 12200, 11680, 11451, 11429, 11473, 11637, 11479, 
11416, 11916, 11575, 11571, 11694, 11764, 11775, 11512, 11760, 
11901, 11566, 12133, 11566, 11497, 11728, 11765, 11489, 12064, 
12338, 11632, 11808, 11671, 12050, 11750, 12117, 12038, 11501, 
11766, 11704, 12261, 11735, 11556, 11989, 11613, 11619, 12430, 
11796, 11620, 11927, 11805, 11907, 12261, 11941, 12203, 12094, 
12347, 12012, 12069, 11969, 11970, 12233, 11964, 12202, 12143, 
11977, 12089, 11963, 12491, 11936, 12416, 12161, 12339, 12270, 
12225, 12263, 12224, 12220, 12226, 12183, 12144, 12242, 12200, 
12225, 12182, 12088, 12046, 12321, 12332, 12166, 12317, 11948, 
12028, 12300, 12013, 12228, 11999, 12085, 11949, 12102, 12130, 
12001, 12240, 12179, 11945, 11953, 12013, 12186, 12212, 12070, 
11961, 12228, 12030, 12163, 11995, 12047, 12081, 11942, 12136, 
11964, 12472, 12035, 11976, 11974, 11986, 12246, 12078, 11996, 
12257, 11878, 12021, 12079, 12203, 12367, 12092, 12390, 12049, 
12155, 12246, 12227, 12100, 12246, 12278, 12033, 12080, 12063, 
11986, 12192, 12053, 12214, 12281, 12165, 11997, 12115, 12156, 
12045, 12261, 12013, 12358, 12101, 12235, 12267, 12351, 12142, 
11942, 12062, 12321, 12008, 12108, 12350, 12080, 12025, 12222, 
12255, 12303, 12542, 11984, 12142, 12199, 12033, 12048, 12105, 
12334, 12104, 12233, 12041, 12113, 12300, 12137, 12295, 12324, 
12339, 12373, 12261, 12004, 11992, 12283, 12208, 12101, 12010, 
12650, 12258, 12201, 12182, 12248, 12052, 12244, 12194, 12232, 
12260, 12301, 12080, 12388, 12242, 12113, 12214, 12082, 12138, 
12045, 12217, 12196, 12331, 12056, 12375, 12355, 12276, 12315, 
12385, 12055, 11994, 12170, 12237, 12178, 12195, 12285, 12342, 
12152, 12173, 11979, 12364, 12476, 12348, 12387, 12216, 12146, 
12336, 12333, 12174, 12389, 12428, 12196, 12383, 12511, 12298, 
12286, 12356, 12330, 12509, 12162, 12163, 12327, 12224, 12160, 
12483, 12308, 12442, 12255, 12601, 12451, 12123, 12155, 12158, 
12271, 12556, 12239, 12132, 12362, 12402, 12335, 12420, 12487, 
12104, 12176, 12488, 12484, 12282, 12324, 12290, 12264, 12274, 
12290, 12266, 12237, 12431, 12478, 12189, 12147, 12262, 12335, 
12414, 12141, 12202, 12145, 12403, 12514, 12462, 12326, 12358, 
12445, 12177, 12350, 12269, 12292, 12354, 12475, 12440, 12568, 
12500, 12155, 12319, 12252, 12323, 12446, 12517, 12557, 12557, 
12235, 12264, 12287, 12249, 12322, 12348, 12558, 12432, 12423, 
12302, 12556, 12488, 12529, 12307, 12464, 12368, 12257, 12224, 
12549, 12460, 12416, 12532, 12256, 12436, 12500, 12472, 12440, 
12291, 12248, 12440, 12254, 12239, 12243, 12454, 12530, 12459, 
12361, 12272, 12409, 12227, 12482, 12481, 12581, 12569, 12381, 
12348, 12194, 12308, 12409, 12229, 12527, 12427, 12416, 12350, 
12240, 12487, 12384, 12489, 12403, 12301, 12542, 12562, 12341, 
12467, 12570, 12249, 12360, 12340, 12435, 12546, 12288, 12532, 
12470, 12302, 12248, 12594, 12225, 12395, 12407, 12454, 12262, 
12276, 12560, 12317, 12576, 11906, 12111, 12086, 12125, 12055, 
12380, 12487, 12194, 12572, 12332, 12427, 12183, 12168, 12062, 
11960, 12419, 12052, 12416, 12271, 12095, 12214, 12058, 12166, 
12345, 12292, 12040, 12127, 12071, 12416, 12268, 12198, 12279, 
12071, 12084, 12152, 12285, 12085, 12131, 12228, 12012, 12096, 
12309, 11979, 12151, 12251, 12066, 12190, 12542, 12392, 12274, 
12047, 12118, 12184, 12053, 12242, 12295, 12162, 12172, 12192, 
12065, 12356, 12350, 12446, 12202, 12452, 12136, 12066, 12274, 
12213, 12235, 12333, 12585, 12379, 12157, 12207, 12178, 12196, 
12418, 12098, 12084, 12296, 12164, 12320, 12443, 12153, 12488, 
12267, 12225, 12299, 12129, 12416, 12229, 12199, 12320, 12218, 
12284, 12156, 12128, 12261, 12241, 12588, 12198, 12347, 12467, 
12511, 12304, 12170, 12328, 12220, 12300, 12390, 12185, 12328, 
12419, 12378, 12482, 12378, 12190, 12108, 12408, 12392, 12385, 
12527, 12265, 12310, 12161, 12448, 12424, 12266, 12392, 12363, 
12363, 12465, 12365, 12487, 12272, 12382, 12427, 12412, 12320, 
12172, 12414, 12375, 12421, 12495, 12243, 12295, 12214, 12319, 
12447, 12525, 12276, 12276, 12503, 12284, 12589, 12322, 12525, 
12404, 12401, 12515, 12259, 12374, 12565, 12441, 12178, 12550, 
12446, 12513, 12584, 12520, 12581, 12265, 12416, 12395, 12213, 
12257, 12485, 12267, 12266, 12509, 12267, 12439, 12334, 12368, 
12505, 12246, 12202, 12281, 12203, 12296, 12489, 12235, 12214, 
12310, 12467, 12548, 12344, 12462, 12271, 12345, 12351, 12709, 
12539, 12560, 12509, 12593, 12517, 12464, 12334, 12476, 12317, 
12296, 12478, 12664, 12252, 12482, 12324, 12617, 12606, 12596, 
12270, 12381, 12598, 12223, 12570, 12611, 12522, 12584, 12320, 
12341, 12306, 12382, 12454, 12507, 12574, 12566, 12472, 12007, 
11969, 12275, 12613, 12182, 11987, 12235, 12013, 12212, 12108, 
12088, 12147, 12244, 12248, 12111, 12231, 12429, 12038, 12225, 
12272, 12183, 12228, 12080, 12089, 12214, 12520, 12270, 12326, 
12036, 12157, 12211, 12363, 12153, 12386, 12144, 12293, 12100, 
12666, 12328, 12326, 12031, 12137, 12554, 12025, 11996, 12102, 
12511, 12757, 12090, 12050, 12439, 12514, 12025, 12091, 12031, 
12215, 12044, 12168, 12161, 12270, 12236, 12102, 12003, 12365, 
12293, 12206, 12286, 12168, 12404, 11997, 12224, 12184, 12305, 
12265, 12299, 12210, 12072, 12246, 12218, 12139, 12163, 12520, 
12164, 12127, 12284, 12318, 12127, 12095, 12295, 12016, 12140, 
12206, 12260, 12469, 12375, 12437, 12159, 12344, 12347, 12054, 
12555, 12196, 12263, 12288, 12346, 12235, 12209, 12311, 12068, 
12085, 12182, 12122, 12293, 12473, 12410, 12035, 12140, 12104, 
12092, 12321, 12112, 12129, 12182, 12140, 12333, 12216, 12160, 
12400, 12274, 12165, 12130, 12523, 12275, 12274, 12153, 12280, 
12347, 12166, 12630, 12411, 12534, 12205, 12368, 12092, 12460, 
12245, 12140, 12371, 12578, 12542, 12439, 12285, 12276, 12432, 
12088, 12513, 12271, 12349, 12444, 12628, 12449, 12378, 12490, 
12344, 12302, 12461, 12538, 12319, 12161, 12337, 12226, 12505, 
12441, 12545, 12490, 12354, 12271, 12564, 12283, 12492, 12241, 
12312, 12488, 12288, 12171, 12456, 12202, 12489, 12197, 12466, 
12309, 12293, 12260, 12418, 12427, 12392, 12158, 12437, 12283, 
12331, 12345, 12376, 12468, 12433, 12438, 12575, 12311, 12332, 
12442, 12541, 12302, 12200, 12349, 12285, 12240, 12538, 12298, 
12236, 12361, 12472, 12504, 12261, 12265, 12261, 12208, 12334, 
12429, 12564, 12560, 12329, 12266, 12209, 12508, 12332, 12353, 
12402, 12461, 12382, 12401, 12232, 12456, 12349, 12563, 12227, 
12492, 12417, 12595, 12396, 12363, 12274, 12446, 12280, 12336, 
12431, 12516, 12442, 12505, 12348, 12392, 12463, 12374, 12163, 
12515, 12640, 12298, 12610, 12290, 12582, 12637, 12477, 12270, 
12450, 12265, 12544, 12620, 12407, 12724, 12372, 12412, 12730, 
12320, 12350, 12358, 12465, 12284, 12432, 12628, 12401, 12629, 
12609, 12304, 12582, 12395, 12455, 12433, 12578, 12505, 12497, 
12608, 12620, 12700, 12356, 12603, 12471, 12570, 12642, 12609, 
12327, 12421, 12421, 12432, 12461, 12404, 12535, 12549, 11930, 
12148, 12193, 12065, 12204, 12631, 12239, 12314, 12204, 12436, 
12478, 12193, 12208, 12143, 12172, 12248, 12267, 12238, 11918, 
12353, 12238, 12081, 12350, 12186, 12066, 12144, 12314, 12471, 
12269, 12255, 12281, 12184, 12226, 12018, 11971, 12315, 12740, 
12262, 12249, 12098, 12008, 12138, 11955, 12631, 12548, 12144, 
12050, 11942, 12197, 12168, 11972, 12262, 11940, 12060, 12273, 
12025, 12110, 12052, 12153, 11944, 12110, 11992, 12167, 12360, 
12028, 12276, 12015, 12265, 12133, 12181, 12054, 12352, 12296, 
12359, 12207, 12327, 12329, 12320, 12425, 12385, 12240, 12572, 
12318, 12222, 12273, 12419, 12286, 12234, 12408, 12480, 12411, 
12254, 12551, 12456, 12773, 12623, 12749, 12652, 12712, 12933, 
12811, 12796), class = "Date"), dlw = structure(c(13525, 13278, 
13058, 13150, 13011, 12972, 12739, 13048, 13226, 12892, 11727, 
11701, 11584, 12772, 11674, 13131, 12129, 11698, 13300, 12983, 
12323, 11452, 12974, 12987, 13233, 12337, 11654, 12221, 11665, 
12184, 12437, 12829, 11871, 12907, 13147, 11628, 11469, 11727, 
13048, 12869, 12305, 12429, 11981, 11550, 11607, 12299, 12176, 
12881, 12362, 12241, 13321, 12765, 11793, 11611, 11782, 12774, 
11847, 11427, 12422, 12869, 13002, 12841, 13208, 12267, 12586, 
11475, 11883, 12823, 13349, 12231, 12330, 12936, 12411, 12849, 
11780, 11764, 12514, 11690, 13350, 13132, 12866, 13166, 13058, 
11803, 13133, 11502, 12278, 11802, 11420, 11630, 11659, 11771, 
12270, 11609, 13148, 11811, 13190, 13025, 13114, 12901, 12259, 
12351, 13301, 12259, 12738, 11679, 12797, 12961, 13010, 12031, 
12392, 13454, 12193, 12689, 11820, 12591, 13284, 11963, 12133, 
13227, 13127, 12613, 13401, 12162, 13082, 11996, 13190, 13141, 
12978, 13026, 13018, 13373, 12081, 13320, 13301, 12162, 12780, 
13512, 13201, 13278, 12103, 12310, 13408, 12164, 13510, 13353, 
13172, 12963, 13235, 13272, 11834, 11895, 13248, 13307, 13394, 
12205, 12521, 12946, 13455, 13284, 13545, 13313, 13399, 13369, 
13103, 13043, 12866, 13368, 11893, 12061, 13237, 12364, 11989, 
13367, 13522, 12830, 12851, 12311, 12217, 12173, 12156, 11784, 
13448, 12063, 12182, 13331, 12502, 13335, 13202, 13273, 12023, 
13447, 13490, 11962, 12096, 13237, 12743, 12329, 13481, 13206, 
13094, 13248, 12543, 12624, 13362, 13212, 13150, 13208, 13106, 
11856, 13065, 12087, 12662, 12618, 12976, 12496, 13244, 13072, 
11971, 12979, 11870, 12444, 12971, 13413, 11911, 12969, 12605, 
12048, 11739, 11972, 12353, 13627, 12904, 12035, 12206, 11924, 
12515, 12992, 12134, 11838, 13396, 12934, 12478, 12107, 13238, 
12499, 12116, 12603, 12365, 12851, 13149, 12323, 13204, 12108, 
12194, 13224, 12589, 13444, 11975, 12263, 13709, 12208, 13255, 
13102, 12035, 12516, 13074, 11803, 13284, 11863, 11900, 12231, 
12994, 12345, 13125, 13649, 12109, 12551, 11968, 13065, 11974, 
13422, 12260, 13156, 12681, 12034, 12033, 12827, 12001, 12897, 
12838, 11652, 12451, 12592, 13357, 12348, 11737, 12305, 13469, 
11903, 12879, 12808, 12996, 12256, 13056, 11888, 13496, 13418, 
13118, 13096, 13245, 11955, 13035, 12029, 12907, 13208, 12083, 
13414, 12593, 13545, 11788, 13198, 13486, 12167, 12864, 11783, 
13090, 12067, 13204, 12956, 12842, 11893, 12212, 11574, 11959, 
12577, 13012, 12150, 11636, 12318, 12713, 12304, 12012, 13028, 
12830, 12816, 13298, 13289, 13606, 12518, 13072, 13013, 13045, 
12935, 11993, 13167, 11987, 13082, 13241, 12930, 12881, 13147, 
12855, 13122, 11706, 12080, 12966, 12446, 11483, 13018, 11640, 
12024, 12400, 11906, 12788, 12580, 12987, 12227, 12324, 11790, 
11861, 13060, 13224, 13267, 12510, 11865, 13311, 13379, 13018, 
13124, 11962, 12224, 13461, 12648, 12529, 13294, 12044, 13194, 
12930, 11956, 11861, 12772, 13498, 13241, 13137, 13290, 13025, 
13159, 12930, 13222, 12278, 11802, 13183, 12221, 12737, 13253, 
12971, 13138, 11924, 12856, 11982, 13093, 11892, 11883, 13098, 
12175, 11823, 12917, 13002, 12240, 13075, 12614, 11928, 13073, 
13176, 12315, 11865, 13383, 11910, 13107, 11869, 13365, 13065, 
13052, 11658, 13204, 12988, 11605, 12423, 11591, 11913, 13059, 
12609, 13302, 13247, 12267, 12839, 13411, 12360, 12769, 11437, 
12803, 13044, 11590, 12819, 13052, 11890, 12860, 12327, 12966, 
11832, 11594, 13226, 12419, 11689, 12238, 11766, 12859, 11833, 
12238, 12761, 12184, 12520, 12992, 13078, 11918, 12299, 13270, 
13384, 12087, 12148, 13094, 12001, 12946, 11771, 12768, 12137, 
12337, 11769, 12551, 12047, 11773, 12008, 11942, 13074, 12374, 
12969, 13412, 13395, 12736, 13261, 12137, 13160, 12064, 13480, 
13229, 13404, 12161, 13005, 12642, 12139, 13354, 13250, 13316, 
12308, 12814, 13466, 12815, 12687, 13426, 12274, 13595, 13354, 
13429, 13503, 12366, 13557, 12270, 13524, 12352, 12496, 13418, 
12300, 13534, 13137, 13381, 13523, 13538, 12708, 13139, 12683, 
12426, 12758, 13267, 12580, 13441, 13370, 13219, 12045, 13262, 
13314, 13486, 12215, 12633, 13350, 12043, 12316, 12129, 12085, 
12299, 12096, 13366, 12231, 13558, 13378, 13121, 13185, 13454, 
12475, 13177, 12391, 12628, 11917, 13135, 13304, 13394, 13200, 
12141, 13427, 13203, 13384, 13578, 13471, 13352, 12356, 13453, 
12518, 12250, 12591, 12204, 13318, 13282, 13444, 13449, 12339, 
13239, 12117, 12213, 12142, 13396, 13238, 12897, 12105, 13458, 
12426, 12480, 13374, 13139, 13314, 13617, 13284, 13345, 13533, 
12332, 13220, 12435, 13091, 12855, 12672, 13091, 12229, 12644, 
12157, 12622, 13225, 12541, 13223, 12267, 13286, 13273, 12433, 
12142, 12749, 12735, 12474, 12622, 12267, 12138, 13127, 12420, 
12641, 13185, 13222, 13340, 12401, 13403, 13342, 12329, 13149, 
13442, 13390, 13411, 12847, 13564, 12593, 13024, 12832, 12241, 
12730, 13347, 12291, 13243, 12268, 13310, 13430, 12288, 12460, 
13762, 12874, 13417, 13593, 13096, 13166, 13338, 12407, 12669, 
12568, 13341, 12848, 13341, 12330, 13156, 13523, 13052, 13504, 
12975, 12696, 13430, 13455, 13545, 12414, 12747, 13482, 13174, 
12731, 13615, 12348, 13179, 12454, 13270, 13645, 12644, 12666, 
13435, 12316, 13203, 12709, 12445, 12529, 13249, 13535, 13469, 
12641, 12841, 13449, 13387, 13728, 13408, 12630, 13503, 13368, 
13317, 13556, 13342, 13126, 12608, 13539, 12968, 13506, 12503, 
12422, 13239, 13108, 12500, 13288, 12404, 13482, 13500, 13311, 
13148, 13377, 12336, 13480, 13222, 13355, 13110, 12653, 12661, 
13573, 12496, 12818, 12899, 13391, 13536, 12750, 12459, 13334, 
13597, 12643, 13152, 13624, 12864, 13408, 13045, 12514, 13378, 
13423, 13047, 12953, 13297, 12473, 13350, 12632, 12334, 13071, 
13516, 12590, 13277, 12884, 13449, 13581, 13376, 13363, 13555, 
13359, 13107, 13400, 13516, 12656, 12599, 13662, 13122, 13548, 
13562, 13490, 12443, 13077, 13260, 13391, 12859, 13357, 13235, 
13477, 13453, 13598, 13513, 13374, 13168, 13369, 13373, 13333, 
12746, 12691, 13483, 12628, 12400, 13424, 12532, 13323, 12579, 
12516, 13414, 13218, 13348, 13065, 13201, 13403, 13431, 12467, 
12646, 12722, 13331, 12473, 13629, 13228, 13086, 13379, 12983, 
13316, 13196, 13592, 13380, 12528, 13122, 13487, 12603, 13411, 
13370, 13443, 13297, 12706, 13705, 13438, 12598, 13178, 13317, 
12887, 13238, 13244, 13629, 13632, 13324, 13725, 13295, 12989, 
13361, 12284, 13192, 11974, 13576, 13197, 13452, 13413, 13159, 
12530, 12371, 12455, 12379, 13539, 13296, 13361, 13175, 12704, 
12438, 12741, 13421, 13283, 13224, 12964, 12362, 12814, 13400, 
12859, 13239, 13297, 13530, 12204, 12794, 12860, 13160, 13442, 
12710, 12428, 13460, 13153, 13188, 12381, 13318, 13361, 13477, 
12981, 12412, 13364, 13262, 12534, 13403, 13543, 13341, 13288, 
13300, 12238, 12749, 12457, 13315, 13542, 12667, 13582, 12200, 
13317, 12639, 13259, 13457, 13236, 12188, 13482, 13360, 13516, 
13418, 12746, 13364, 13355, 12793, 13344, 12212, 13467, 12418, 
13374, 13552, 13443, 13503, 12218, 12504, 12516, 12359, 13381, 
13308, 13138, 13042, 13572, 13375, 12665, 13446, 13278, 13409, 
13521, 13352, 13266, 13488, 12904, 12892, 12944, 13225, 12643, 
13553, 12564, 12917, 13429, 13350, 13174, 13238, 12905, 12545, 
13368, 13552, 13436, 13486, 13574, 12850, 13501, 12372, 13547, 
13476, 13463, 12728, 13129, 13317, 12501, 13339, 13540, 13217, 
13336, 13283, 12433, 12963, 13601, 12944, 12441, 13535, 13390, 
13472, 13448, 13508, 12852, 13076, 13540, 13292, 13336, 12682, 
13442, 13267, 13338, 13565, 13561, 13134, 13057, 13603, 12541, 
12924, 13137, 12327, 13308, 12608, 13064, 13363, 13600, 13384, 
12631, 12426, 13488, 13542, 12386, 13292, 13459, 13184, 12813, 
12651, 13409, 12747, 13229, 13319, 13493, 13290, 13325, 13094, 
12446, 13313, 13670, 13610, 13388, 13308, 13105, 13353, 13651, 
13194, 13357, 12331, 12340, 13392, 13443, 12345, 13278, 13515, 
13582, 13410, 13419, 13250, 13088, 13414, 12241, 13558, 13573, 
12760, 13402, 13138, 12586, 12979, 13270, 13209, 12639, 13055, 
13461, 13467, 12028, 13271, 12355, 13287, 13426, 12082, 12357, 
13403, 13432, 13317, 12432, 12161, 13391, 12537, 12206, 12534, 
13546, 13208, 12343, 12882, 12416, 13487, 13194, 12616, 13461, 
12609, 12514, 13509, 12144, 13254, 12537, 13369, 12206, 13477, 
13384, 12549, 13208, 13713, 13583, 13433, 12082, 13438, 12781, 
13277, 13138, 13169, 13311, 12922, 12888, 12795, 13384, 12571, 
12034, 12273, 12134, 13439, 13150, 12792, 13370, 12461, 13343, 
12191, 13270, 13588, 13488, 12259, 13350, 12555, 12541, 12030, 
13523, 12690, 13485, 12423, 12454, 13433, 12220, 13283, 13218, 
13169, 13257, 13399, 13338, 13309, 13455, 12354, 12213, 12288, 
12381, 13216, 13283, 12274, 12617, 12583, 13533, 13344, 12701, 
13568, 13435, 13301, 13298, 13244, 13285, 13413, 13569, 13345, 
12299, 12832, 12577, 13174, 13325, 13173, 13330, 13002, 12520, 
12077, 13250, 13162, 13199, 13465, 13321, 13328, 12620, 13271, 
12812, 12414, 13297, 13458, 13422, 12318, 12182, 12705, 13284, 
13396, 13528, 13345, 12488, 12583, 13516, 12543, 13038, 12239, 
12480, 12539, 13626, 13258, 13406, 13401, 13262, 13415, 13643, 
13105, 13510, 13493, 13223, 12558, 12408, 12446, 13339, 13308, 
13497, 13393, 13492, 13425, 13452, 13559, 13522, 13418, 13222, 
13421, 12288, 12570, 13348, 12586, 13488, 13447, 13248, 13490, 
13384, 13598, 13266, 12435, 13231, 12466, 13300, 13499, 12287, 
13356, 13282, 13257, 13280, 13298, 13197, 13337, 12835, 13535, 
13340, 13018, 12310, 13217, 12541, 12551, 13603, 13415, 13398, 
13600, 12817, 13140, 13512, 13080, 13358, 13281, 12467, 12518, 
12511, 13481, 12314, 13451, 13448, 13466, 13548, 12409, 12398, 
13370, 12661, 13222, 12840, 13526, 13313, 13453, 13285, 12442, 
13508, 13326, 13345, 13564, 13444, 13421, 13391, 13362, 12618, 
12862, 13361, 12725, 12498, 13401, 13464, 13428, 13310, 12387, 
12709, 13394, 12806, 13274, 13483, 13287, 12582, 13231, 13245, 
13326, 13516, 12211, 13397, 13465, 12358, 13375, 13149, 13465, 
13535, 13443, 12507, 13337, 12475, 13487, 12783, 13326, 12869, 
12488, 13364, 13575, 13138, 13219, 12922, 13592, 13303, 13287, 
13400, 13324, 13442, 12711, 13284, 13354, 13293, 13378, 13320, 
13488, 13297, 13310, 13382, 13548, 13193, 12908, 12712, 13235, 
13385, 13445, 13353, 13183, 13366, 13321, 12508, 12683, 13105, 
13580, 13359, 12579, 13409, 12308, 13271, 13279, 13543, 13305, 
13487, 12383, 13471, 13605, 13290, 12777, 13361, 12291, 13588, 
12337, 12365, 13050, 12502, 13440, 13357, 12768, 13549, 13291, 
12536, 12513, 13231, 12328, 12374, 12725, 12353, 12366, 13268, 
12426, 13515, 12986, 12629, 12382, 12331, 12086, 12250, 12125, 
13446, 13091, 13303, 12454, 13203, 12321, 12371, 13178, 12372, 
13152, 12157, 13667, 12232, 13318, 13420, 13528, 12112, 13278, 
12022, 13401, 13740, 13135, 13699, 13238, 13203, 13386, 13209, 
13423, 13730, 12306, 13562, 13508, 12635, 12612, 12579, 13739, 
13354, 13347, 12957, 13302, 12716, 12413, 13474, 13315, 13345, 
13430, 12647, 13469, 12363, 12560, 12998, 13464, 13410, 13140, 
12859, 13090, 13138, 13251, 13294), class = "Date"), dfi = structure(c(NA, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, 11919, 12162, 12366, NA, 
12351, NA, 13377, 12457, NA, NA, NA, 12173, NA, NA, NA, NA, NA, 
NA, 12392, NA, 13434, NA, 12564, NA, NA, 12401, 11570, 12464, 
NA, NA, 13060, NA, NA, 11822, 12341, NA, NA, NA, NA, 13037, NA, 
NA, NA, 11767, 12282, NA, 12007, 11799, 13120, NA, NA, NA, NA, 
12554, 13129, 12065, 12046, NA, NA, 12738, NA, NA, 12685, NA, 
12231, 12046, NA, 11857, NA, NA, NA, NA, 13352, 12335, NA, 11624, 
NA, 12444, 11566, 12214, 11946, 13389, NA, 12401, NA, 12657, 
NA, NA, NA, NA, NA, 12871, NA, NA, NA, NA, NA, NA, NA, 12473, 
NA, NA, NA, NA, 11992, NA, NA, 13166, 12446, NA, NA, NA, NA, 
12562, NA, NA, NA, NA, NA, NA, NA, NA, 12639, NA, NA, NA, NA, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 12279, 12004, 
NA, NA, NA, 12504, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 13440, 
NA, 12385, 12297, NA, NA, 12225, NA, NA, NA, 13316, 12468, 12550, 
NA, NA, 12894, NA, 12188, 12647, NA, 13355, NA, NA, NA, NA, NA, 
NA, 13384, 13381, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
NA, NA, NA, 12344, NA, NA, 13539, 13535, NA, NA, NA, NA, NA, 
NA, 12459, NA, NA, NA, 12136, NA, 13149, NA, 12019, NA, NA, NA, 
NA, 12421, 13074, 12110, NA, NA, 13355, 12255, NA, NA, NA, 13389, 
NA, 12872, NA, NA, 12760, NA, NA, 12826, NA, 12294, 12805, NA, 
13505, NA, NA, 12542, NA, 13575, NA, NA, NA, 12911, NA, 13081, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, 13396, 13059, NA, 12508, 
NA, NA, NA, 13379, 13166, 12664, NA, 12189, NA, NA, 12183, 13359, 
NA, NA, NA, 12061, 12848, NA, 13219, NA, NA, NA, NA, NA, 12426, 
NA, NA, NA, NA, NA, 13211, NA, NA, 13564, NA, NA, NA, NA, NA, 
13337, NA, NA, 12375, NA, 12252, NA, 12277, NA, NA, NA, 12056, 
12589, 12253, 12549, 13316, NA, 12308, NA, NA, NA, 13239, 12132, 
NA, NA, NA, NA, NA, NA, 13431, NA, NA, 13638, NA, 12404, NA, 
12529, NA, NA, NA, NA, NA, NA, NA, 12288, 13205, NA, 12562, 12160, 
NA, 11736, NA, 13713, NA, NA, 13462, NA, 12969, 13096, 12009, 
12432, NA, NA, NA, 13628, 12261, NA, NA, NA, NA, 12069, 13192, 
NA, 13088, 13059, NA, NA, NA, NA, 12600, 12323, 13218, NA, NA, 
NA, NA, NA, NA, NA, NA, NA, 12435, NA, NA, NA, 13302, NA, NA, 
13203, 13596, 12501, NA, 12147, 12287, NA, 13380, 12252, NA, 
NA, 13004, NA, NA, 12368, NA, NA, 13126, 12106, NA, 12054, NA, 
NA, NA, NA, NA, NA, NA, NA, 12594, NA, 12266, NA, NA, NA, NA, 
NA, 13371, NA, NA, NA, NA, 11680, NA, NA, NA, NA, NA, 12328, 
NA, NA, NA, 13094, 13017, NA, NA, 11912, 12687, NA, NA, 12515, 
12772, NA, 12458, NA, NA, NA, NA, NA, NA, NA, 12629, 13105, 13135, 
NA, NA, 12044, NA, 12472, NA, 12948, 13560, 12412, 12308, 12334, 
12166, NA, 12476, NA, NA, NA, NA, NA, 12500, NA, 12597, NA, NA, 
NA, 12327, NA, 13420, 12359, NA, NA, NA, 12690, NA, NA, 13428, 
13542, NA, 12676, NA, NA, NA, NA, NA, NA, 13476, NA, 12550, NA, 
NA, 12732, NA, NA, NA, NA, NA, 13595, NA, NA, 13331, NA, NA, 
12972, NA, NA, NA, 12298, NA, NA, NA, 12649, 13164, NA, 12561, 
12765, 12640, 12347, NA, 12213, NA, 13344, NA, NA, NA, NA, NA, 
12756, NA, 13165, 13580, 13158, NA, NA, NA, NA, 12603, NA, NA, 
NA, NA, NA, NA, 13577, NA, 12867, 13376, 13405, 12574, NA, NA, 
NA, NA, 12581, NA, 12529, 13363, 12668, NA, NA, NA, 12412, NA, 
NA, 12671, NA, NA, NA, NA, NA, NA, NA, 13439, NA, 12751, NA, 
13607, 13498, NA, 13473, 12789, NA, 13323, NA, 13047, NA, 12776, 
NA, NA, 13556, 12543, 12962, 13676, NA, 12949, 13379, 12871, 
NA, 12624, 13442, NA, NA, NA, 13611, NA, NA, 12789, NA, NA, NA, 
NA, NA, NA, NA, 13651, NA, NA, 13349, NA, 12729, NA, 12431, NA, 
NA, NA, 13037, NA, NA, NA, NA, NA, NA, NA, 12808, 13363, 12816, 
NA, 13613, NA, 12802, NA, NA, 13406, NA, NA, NA, NA, NA, 13700, 
NA, NA, NA, NA, NA, NA, 13404, NA, 12693, NA, NA, 13335, 13377, 
NA, 13495, NA, NA, 13454, 12807, NA, NA, NA, NA, 13281, NA, NA, 
NA, NA, 13383, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 13563, 
12865, NA, NA, NA, NA, 12946, NA, NA, NA, NA, NA, 12860, NA, 
NA, NA, NA, NA, 13103, NA, 12903, 13566, NA, NA, NA, 13364, 12635, 
NA, NA, 13107, 13732, NA, 13247, NA, NA, NA, NA, NA, NA, NA, 
NA, NA, NA, NA, 12628, NA, NA, 13746, NA, 13532, NA, NA, NA, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 12992, NA, 
NA, NA, 13342, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 13611, 
NA, NA, NA, NA, NA, 13433, NA, 12760, 12700, NA, NA, NA, NA, 
NA, NA, NA, 12691, 12918, NA, NA, 13401, NA, NA, NA, NA, 13552, 
NA, NA, NA, NA, 13384, NA, NA, 13293, NA, NA, NA, NA, NA, NA, 
NA, 12805, NA, NA, 13339, NA, NA, NA, NA, NA, NA, NA, 13497, 
NA, 13644, NA, 12196, NA, NA, NA, NA, NA, NA, 12660, NA, 12902, 
NA, NA, NA, NA, NA, 12930, 13398, NA, NA, NA, NA, 12823, 13298, 
NA, NA, NA, NA, NA, 12915, 13384, NA, NA, NA, NA, 12844, NA, 
NA, NA, NA, NA, NA, NA, 13415, 12915, NA, NA, NA, NA, NA, NA, 
NA, NA, 12466, NA, 13262, NA, NA, 13088, NA, 12709, NA, NA, NA, 
NA, NA, 12792, NA, NA, NA, NA, NA, NA, NA, NA, NA, 13441, NA, 
NA, NA, NA, NA, NA, 12379, NA, 12949, 12794, NA, NA, NA, NA, 
NA, NA, 13317, NA, NA, NA, NA, NA, NA, NA, NA, NA, 13456, NA, 
13318, NA, 13089, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
NA, 13659, NA, 12981, NA, NA, NA, NA, NA, NA, 12952, NA, NA, 
NA, NA, NA, 12554, NA, NA, NA, 12971, NA, NA, NA, NA, NA, NA, 
NA, NA, NA, NA, 13739, NA, NA, NA, NA, NA, NA, NA, NA, NA, 13475, 
NA, 12743, NA, 13082, NA, NA, NA, NA, 12966, 12978, NA, NA, NA, 
NA, NA, NA, 13474, 12940, NA, NA, NA, NA, NA, NA, NA, NA, 12985, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 12516, 12568, NA, NA, 
13229, NA, NA, NA, NA, NA, NA, NA, NA, 12733, NA, NA, 13253, 
NA, NA, NA, 13155, NA, NA, 12846, NA, NA, NA, 12816, NA, 12549, 
NA, NA, 12517, 12902, NA, NA, NA, NA, 12390, NA, 13345, 13354, 
NA, NA, NA, 12808, 13459, NA, NA, NA, 13258, NA, 12935, 12817, 
NA, 12348, NA, NA, NA, 12353, NA, NA, 13095, NA, NA, NA, NA, 
12460, NA, 13154, NA, NA, NA, NA, 13365, NA, 13359, NA, 13284, 
12756, 12511, 12696, NA, NA, NA, NA, 12820, NA, 12809, NA, NA, 
NA, 12426, NA, NA, 12823, 12335, NA, 13506, NA, NA, 12985, NA, 
12455, NA, NA, NA, NA, NA, NA, NA, NA, 13585, 13336, NA, 12932, 
NA, NA, 12718, NA, 12985, NA, NA, 13451, NA, NA, NA, NA, NA, 
NA, NA, NA, NA, 12801, NA, NA, NA, NA, NA, NA, 13606, 12640, 
12286, NA, NA, NA, NA, NA, NA, NA, NA, 13626, NA, NA, NA, NA, 
12493, 13496, 13192, NA, NA, NA, NA, NA, NA, NA, 12786, 13398, 
12718, 13007, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
12733, 12576, 12627, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
NA, NA, 12538, 12828, NA, 12983, NA, NA, NA, NA, NA, NA, NA, 
12940, NA, 12596, NA, NA, 13398, NA, NA, NA, NA, NA, NA, NA, 
NA, NA, NA, 13720, 12529, NA, 12857, NA, NA, NA, NA, NA, 13473, 
NA, NA, NA, NA, NA, 12570, NA, NA, NA, 12518, NA, NA, NA, NA, 
12645, 12814, NA, 13299, NA, 13456, NA, NA, NA, NA, NA, NA, NA, 
NA, NA, NA, NA, NA, NA, 13129, 13573, NA, 13328, 12704, NA, NA, 
NA, NA, 12555, 13724, NA, 13216, NA, NA, NA, 13412, NA, NA, NA, 
NA, 12970, NA, NA, 13398, NA, NA, NA, NA, NA, 12739, NA, 12895, 
NA, 12886, NA, 13434, 13287, NA, NA, NA, NA, NA, NA, NA, NA, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 13419, 
12869, NA, NA, NA, NA, NA, NA, NA, 12668, NA, NA, NA, NA, NA, 
NA, 12563, NA, NA, NA, NA, NA, 12779, NA, NA, NA, NA, NA, 13562, 
NA, NA, 13088, NA, 13036, NA, NA, 13523, NA, NA, NA, 12873, NA, 
12897, 12990, NA, 12512, 13488, NA, NA, NA, 13611, 13427, NA, 
13462, 12470, 12749, 12733, NA, NA, NA, NA, NA, 12630, NA, NA, 
12511, NA, 12916, NA, NA, NA, NA, NA, 12254, NA, NA, NA, NA, 
NA, NA, NA, NA, NA, NA, NA, NA, 12501, NA, NA, NA, NA, NA, NA, 
NA, NA, 13415, NA, 13348, 12596, NA, NA, NA, NA, 12749, NA, 12990, 
12709, NA, NA, NA, NA, NA, NA, NA, NA, NA), class = "Date"), 
    gtol = structure(as.integer(c(2, 1, 1, 2, 2, 1, 2, 2, 2, 
    1, 2, 1, 2, 2, 1, 1, 2, 2, 1, 2, 2, 2, 1, 1, 2, 2, 2, 2, 
    2, 1, 1, 1, 1, 2, 2, 2, 2, 1, 2, 2, 2, 2, 1, 2, 2, 2, 1, 
    1, 1, 2, 1, 1, 1, 2, 2, 2, 2, 2, 2, 1, 2, 2, 1, 1, 2, 1, 
    2, 2, 2, 2, 2, 2, 1, 2, 2, 1, 2, 2, 2, 1, 2, 2, 1, 2, 2, 
    1, 2, 2, 1, 2, 2, 2, 2, 1, 1, 1, 1, 2, 2, 1, 2, 1, 2, 1, 
    1, 2, 1, 1, 1, 1, 2, 1, 2, 2, 2, 2, 1, 2, 1, 2, 2, 1, 1, 
    1, 2, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 2, 2, 
    2, 2, 2, 1, 2, 2, 1, 2, 2, 1, 2, 1, 1, 2, 2, 2, 2, 2, 1, 
    2, 1, 2, 2, 2, 2, 2, 1, 2, 1, 2, 2, 2, 2, 2, 1, 1, 2, 2, 
    2, 2, 2, 2, 2, 2, 1, 2, 2, 2, 2, 1, 2, 1, 2, 2, 2, 2, 2, 
    2, 2, 2, 1, 2, 2, 2, 1, 1, 2, 1, 1, 1, 1, 2, 2, 2, 2, 1, 
    1, 2, 2, 2, 1, 2, 2, 1, 2, 1, 2, 2, 2, 2, 1, 2, 2, 2, 2, 
    2, 2, 2, 1, 1, 2, 2, 2, 1, 2, 2, 2, 1, 1, 2, 2, 2, 2, 2, 
    1, 1, 1, 2, 2, 2, 1, 1, 2, 1, 1, 2, 1, 2, 2, 2, 1, 1, 1, 
    1, 2, 1, 1, 1, 2, 2, 1, 2, 2, 1, 1, 2, 2, 1, 1, 2, 1, 2, 
    2, 2, 1, 2, 2, 2, 2, 1, 1, 1, 1, 2, 1, 1, 2, 1, 2, 2, 2, 
    1, 1, 1, 2, 1, 1, 2, 2, 2, 2, 2, 2, 1, 1, 2, 2, 1, 1, 2, 
    2, 1, 1, 2, 1, 2, 2, 2, 1, 2, 2, 1, 2, 2, 2, 2, 1, 2, 2, 
    1, 1, 1, 1, 2, 1, 2, 2, 1, 1, 2, 1, 2, 1, 2, 1, 2, 1, 2, 
    1, 2, 2, 1, 1, 2, 1, 1, 1, 1, 1, 2, 1, 2, 2, 1, 2, 2, 1, 
    2, 2, 1, 2, 2, 2, 1, 1, 2, 1, 2, 2, 1, 1, 2, 1, 1, 1, 2, 
    1, 1, 2, 1, 2, 1, 1, 1, 2, 2, 2, 1, 1, 1, 2, 1, 2, 2, 2, 
    1, 2, 1, 2, 1, 1, 2, 2, 2, 1, 2, 2, 2, 1, 2, 1, 1, 2, 2, 
    2, 1, 2, 2, 2, 2, 1, 1, 2, 1, 1, 1, 2, 1, 1, 2, 1, 2, 2, 
    1, 1, 1, 2, 2, 1, 1, 2, 1, 2, 1, 2, 2, 2, 1, 1, 1, 2, 1, 
    2, 2, 2, 1, 2, 2, 1, 2, 2, 2, 2, 1, 2, 1, 1, 1, 1, 2, 2, 
    2, 1, 2, 2, 2, 2, 1, 2, 2, 2, 2, 1, 1, 1, 2, 2, 2, 2, 2, 
    2, 2, 2, 1, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 1, 2, 2, 1, 2, 
    2, 2, 1, 2, 2, 1, 2, 2, 1, 2, 1, 2, 1, 2, 1, 2, 2, 1, 1, 
    2, 1, 1, 2, 1, 1, 2, 1, 2, 2, 2, 1, 2, 1, 1, 2, 1, 1, 1, 
    1, 2, 2, 1, 1, 1, 2, 1, 2, 2, 1, 1, 2, 1, 2, 2, 1, 2, 2, 
    1, 2, 1, 1, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 2, 2, 2, 2, 1, 
    1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 1, 1, 
    1, 2, 1, 2, 2, 2, 2, 2, 1, 2, 1, 1, 1, 1, 2, 2, 1, 2, 2, 
    2, 1, 2, 2, 1, 1, 1, 2, 1, 1, 1, 2, 1, 2, 2, 2, 1, 2, 2, 
    1, 2, 1, 2, 2, 2, 1, 2, 2, 2, 2, 1, 2, 2, 2, 1, 2, 1, 2, 
    1, 2, 2, 1, 1, 2, 2, 2, 2, 1, 2, 2, 1, 1, 1, 1, 1, 2, 1, 
    2, 2, 2, 2, 1, 1, 2, 1, 2, 2, 1, 2, 1, 1, 2, 2, 1, 1, 2, 
    2, 1, 1, 1, 1, 1, 2, 1, 2, 1, 2, 2, 2, 2, 2, 1, 2, 2, 2, 
    1, 2, 1, 1, 1, 2, 2, 2, 1, 2, 1, 2, 2, 1, 2, 2, 1, 1, 2, 
    2, 2, 2, 1, 2, 1, 2, 1, 1, 2, 2, 2, 2, 2, 2, 1, 2, 1, 2, 
    2, 2, 1, 1, 1, 1, 2, 1, 1, 2, 1, 2, 2, 1, 1, 2, 2, 2, 1, 
    2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 2, 1, 
    1, 2, 2, 1, 1, 2, 2, 1, 2, 1, 2, 1, 2, 2, 2, 1, 2, 1, 1, 
    1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 2, 2, 
    2, 2, 1, 1, 2, 1, 1, 1, 1, 1, 2, 2, 2, 1, 2, 2, 2, 2, 2, 
    2, 1, 2, 1, 1, 2, 2, 1, 1, 1, 2, 2, 2, 1, 2, 2, 1, 2, 1, 
    2, 2, 2, 2, 2, 1, 2, 2, 2, 2, 1, 2, 1, 2, 2, 2, 1, 1, 2, 
    2, 2, 1, 2, 2, 2, 1, 2, 1, 1, 2, 2, 1, 2, 2, 2, 2, 2, 2, 
    2, 2, 2, 1, 2, 2, 1, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 2, 1, 
    2, 1, 1, 2, 2, 2, 2, 2, 1, 2, 1, 1, 2, 2, 2, 1, 1, 2, 1, 
    1, 2, 2, 1, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
    1, 2, 2, 2, 2, 1, 2, 2, 2, 1, 2, 1, 2, 1, 1, 2, 1, 1, 2, 
    2, 1, 2, 2, 1, 2, 2, 1, 1, 2, 1, 2, 1, 2, 1, 1, 2, 1, 1, 
    1, 1, 1, 1, 2, 2, 2, 1, 2, 1, 2, 2, 2, 2, 2, 1, 2, 2, 2, 
    2, 1, 1, 2, 2, 2, 1, 2, 2, 2, 1, 2, 1, 1, 1, 1, 1, 2, 2, 
    2, 1, 2, 2, 2, 2, 2, 1, 2, 2, 1, 1, 2, 2, 2, 2, 1, 2, 2, 
    2, 1, 2, 2, 1, 2, 1, 2, 2, 1, 2, 2, 2, 2, 2, 1, 2, 1, 2, 
    2, 2, 1, 2, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 2, 2, 
    2, 1, 2, 2, 1, 1, 2, 1, 1, 2, 1, 2, 1, 1, 2, 2, 1, 1, 2, 
    1, 1, 2, 2, 2, 2, 2, 2, 1, 1, 2, 2, 2, 1, 2, 1, 2, 1, 2, 
    2, 2, 2, 2, 1, 2, 1, 2, 2, 2, 2, 2, 2, 1, 1, 2, 1, 2, 1, 
    2, 2, 1, 1, 1, 1, 2, 2, 2, 2, 1, 1, 2, 2, 2, 1, 2, 1, 1, 
    1, 2, 2, 1, 2, 2, 2, 1, 2, 2, 2, 2, 2, 2, 1, 2, 2, 1, 1, 
    2, 2, 1, 1, 2, 2, 2, 1, 2, 1, 2, 1, 1, 2, 1, 1, 2, 2, 2, 
    1, 2, 2, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 2, 2, 2, 1, 2, 
    2, 1, 1, 2, 2, 2, 2, 1, 2, 1, 2, 2, 1, 1, 1, 1, 2, 1, 2, 
    2, 2, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 1, 1, 2, 
    2, 2, 2, 2, 1, 2, 2, 1, 1, 1, 2, 1, 2, 2, 2, 1, 2, 2, 1, 
    2, 1, 1, 2, 2, 1, 1, 2, 2, 2, 1, 2, 2, 2, 1, 1, 2, 2, 1, 
    2, 2, 2, 2, 2, 1, 2, 2, 1, 2, 1, 2, 2, 2, 1, 2, 1, 2, 1, 
    1, 2, 1, 1, 2, 2, 2, 1, 2, 1, 1, 2, 2, 1, 2, 1, 2, 1, 2, 
    1, 1, 1, 2, 2, 2, 2, 1, 2, 2, 2, 1, 2, 2, 1, 2, 2, 2, 2, 
    1, 2, 2, 2, 2, 2, 1, 2, 2, 1, 1, 1, 2, 2, 2, 2, 1, 1, 2, 
    2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 2, 2, 1, 1, 2, 2, 1, 1, 2, 
    2, 1, 1, 1, 1, 1, 2, 1, 2, 2, 2, 2, 1, 1, 2, 2, 2, 2, 2, 
    2, 1, 2, 2, 1, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 2, 2, 1, 1, 
    2, 1, 1, 1, 2, 2, 2, 2, 2, 2, 1, 1, 1, 2, 1, 2, 1, 1, 1, 
    2, 1, 2, 2, 2, 1, 1, 2, 2, 2, 2, 2, 2, 2, 1, 2, 1, 2, 2, 
    2, 2, 2, 1, 2, 2, 2, 2, 2)), .Label = c("IFG", "IGT"), class = "factor"), 
    grp = structure(as.integer(c(2, 1, 1, 1, 1, 2, 2, 1, 2, 1, 
    2, 1, 2, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 
    2, 2, 1, 1, 1, 2, 2, 2, 2, 1, 1, 2, 2, 1, 2, 1, 2, 2, 2, 
    2, 1, 1, 1, 2, 2, 2, 2, 1, 1, 1, 2, 2, 1, 1, 1, 1, 1, 2, 
    1, 1, 2, 2, 2, 2, 1, 1, 1, 1, 2, 1, 2, 1, 1, 2, 1, 2, 1, 
    1, 1, 2, 1, 2, 1, 2, 1, 1, 1, 1, 2, 2, 1, 2, 1, 2, 1, 1, 
    2, 1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 
    2, 1, 2, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 
    2, 1, 1, 2, 1, 1, 2, 2, 2, 1, 2, 1, 1, 1, 2, 2, 2, 1, 1, 
    1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 
    1, 1, 1, 1, 1, 2, 2, 1, 2, 1, 1, 1, 2, 2, 2, 1, 2, 1, 2, 
    2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 
    1, 1, 1, 1, 1, 2, 2, 1, 1, 1, 2, 1, 1, 1, 2, 1, 2, 1, 2, 
    2, 2, 2, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 2, 2, 1, 
    1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 
    1, 1, 1, 2, 2, 1, 1, 2, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 
    1, 1, 2, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 2, 2, 2, 2, 1, 
    2, 1, 2, 2, 2, 2, 1, 2, 1, 2, 2, 2, 1, 2, 1, 2, 2, 2, 2, 
    1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 1, 2, 1, 2, 2, 2, 1, 2, 2, 
    1, 1, 1, 2, 1, 2, 2, 1, 2, 2, 1, 2, 2, 2, 1, 2, 1, 1, 1, 
    1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 2, 2, 1, 2, 2, 
    1, 1, 2, 1, 1, 1, 1, 2, 1, 2, 2, 1, 1, 1, 2, 1, 2, 1, 1, 
    1, 1, 2, 1, 2, 2, 1, 2, 2, 1, 2, 2, 1, 1, 1, 2, 1, 2, 1, 
    2, 1, 1, 2, 2, 1, 2, 1, 2, 2, 1, 1, 1, 2, 1, 1, 1, 1, 1, 
    1, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 
    1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 2, 1, 1, 1, 1, 2, 
    1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 2, 1, 2, 1, 2, 2, 1, 1, 1, 
    1, 1, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 
    1, 2, 1, 2, 1, 1, 2, 2, 2, 1, 1, 2, 1, 1, 1, 1, 2, 2, 2, 
    2, 2, 1, 1, 2, 2, 1, 1, 1, 2, 1, 2, 1, 2, 1, 2, 1, 1, 1, 
    1, 1, 1, 1, 2, 2, 2, 1, 2, 2, 2, 1, 1, 2, 1, 1, 2, 1, 2, 
    1, 1, 1, 1, 2, 1, 2, 2, 1, 1, 2, 2, 2, 2, 1, 1, 1, 1, 1, 
    1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 2, 1, 1, 2, 2, 1, 1, 
    1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    2, 2, 1, 2, 2, 2, 2, 2, 1, 2, 1, 2, 1, 2, 2, 2, 1, 2, 2, 
    2, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 
    1, 1, 2, 2, 2, 2, 1, 2, 2, 1, 2, 1, 1, 2, 1, 1, 1, 2, 2, 
    2, 2, 2, 1, 1, 1, 1, 1, 2, 2, 2, 1, 2, 1, 1, 2, 1, 1, 2, 
    1, 1, 1, 2, 2, 2, 1, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 2, 2, 
    2, 1, 2, 1, 1, 1, 2, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 
    1, 1, 1, 2, 1, 1, 2, 1, 2, 2, 2, 1, 1, 2, 2, 2, 1, 2, 1, 
    1, 1, 1, 2, 2, 2, 2, 1, 1, 2, 2, 1, 2, 2, 2, 1, 1, 2, 2, 
    2, 2, 2, 1, 2, 1, 2, 2, 1, 2, 2, 1, 1, 1, 1, 1, 2, 2, 2, 
    1, 2, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 2, 1, 1, 1, 2, 1, 
    1, 2, 2, 2, 2, 2, 1, 1, 1, 1, 2, 2, 1, 2, 1, 2, 2, 2, 2, 
    1, 2, 2, 2, 2, 2, 2, 2, 2, 1, 2, 1, 1, 2, 2, 1, 2, 1, 1, 
    2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 1, 1, 2, 2, 2, 1, 2, 1, 
    2, 1, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 2, 1, 1, 2, 1, 2, 
    1, 2, 1, 1, 2, 1, 2, 2, 2, 1, 1, 2, 1, 1, 1, 1, 2, 2, 1, 
    1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 2, 1, 2, 2, 1, 2, 2, 1, 2, 
    1, 2, 2, 2, 2, 1, 2, 1, 1, 1, 1, 1, 2, 2, 2, 2, 1, 1, 1, 
    2, 1, 1, 2, 1, 2, 2, 2, 2, 1, 1, 1, 1, 2, 2, 1, 1, 1, 1, 
    1, 1, 2, 2, 1, 2, 2, 1, 2, 2, 1, 1, 2, 1, 1, 1, 1, 2, 1, 
    2, 2, 1, 1, 1, 1, 1, 2, 1, 1, 1, 2, 2, 1, 1, 1, 1, 1, 1, 
    2, 2, 2, 2, 2, 2, 2, 1, 1, 2, 2, 2, 1, 2, 1, 1, 1, 1, 1, 
    1, 1, 2, 1, 2, 1, 2, 1, 1, 2, 1, 2, 1, 2, 1, 1, 1, 2, 2, 
    1, 1, 2, 2, 2, 1, 2, 1, 1, 1, 2, 2, 1, 2, 2, 1, 1, 1, 1, 
    1, 1, 2, 1, 2, 2, 1, 2, 1, 2, 2, 1, 1, 2, 1, 2, 1, 1, 2, 
    2, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 2, 1, 1, 1, 1, 1, 1, 1, 
    2, 1, 2, 1, 2, 2, 1, 1, 2, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 
    1, 1, 2, 1, 1, 2, 1, 2, 2, 2, 2, 2, 1, 1, 1, 1, 2, 1, 2, 
    2, 2, 1, 2, 2, 1, 2, 2, 1, 2, 1, 1, 2, 2, 1, 2, 2, 1, 2, 
    2, 2, 2, 1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 2, 1, 2, 1, 2, 1, 
    2, 1, 2, 2, 1, 2, 1, 2, 2, 1, 1, 1, 2, 1, 2, 1, 2, 2, 1, 
    1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 1, 1, 1, 2, 1, 2, 1, 2, 
    1, 1, 2, 1, 1, 2, 2, 2, 2, 1, 1, 1, 2, 1, 1, 2, 1, 2, 2, 
    2, 2, 1, 2, 2, 1, 1, 2, 1, 1, 2, 1, 1, 2, 2, 1, 1, 1, 1, 
    2, 1, 2, 2, 1, 1, 1, 2, 2, 2, 1, 2, 1, 1, 1, 1, 1, 1, 2, 
    2, 1, 2, 2, 2, 2, 1, 2, 2, 2, 1, 2, 1, 2, 2, 2, 1, 1, 1, 
    1, 2, 2, 1, 1, 1, 1, 2, 1, 1, 1, 2, 1, 2, 2, 2, 2, 2, 1, 
    1, 2, 1, 1, 2, 2, 2, 2, 2, 1, 2, 1, 1, 2, 2, 2, 2, 2, 1, 
    1, 2, 2, 2, 2, 1, 1, 2, 2, 2, 1, 2, 2, 2, 2, 2, 1, 1, 2, 
    1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 1, 2, 1, 2, 2, 1, 1, 1, 1, 
    2, 2, 2, 2, 2, 1, 2, 2, 2, 1, 2, 1, 1, 1, 1, 1, 1, 2, 2, 
    2, 2, 2, 1, 1, 1, 2, 2, 2, 2, 2, 1, 1, 2, 2, 2, 1, 2, 2, 
    2, 1, 1, 2, 2, 1, 1, 2, 1, 2, 2, 1, 2, 1, 2, 2, 1, 2, 2, 
    2, 2, 1, 2, 2, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 1, 1, 1, 1, 
    2, 2, 2, 1, 2, 1, 2, 1, 2, 2, 1, 1, 2, 2, 1, 2, 1, 1, 1, 
    2, 1, 2, 2, 2, 2, 2, 2, 1, 2, 1, 1, 1, 1, 2, 1, 1, 1, 1, 
    1, 1, 1, 2, 1, 1, 2, 2, 2, 1, 1, 1, 1, 2, 1, 1, 2, 1, 1, 
    1, 1, 1, 1, 1, 1, 1, 1)), .Label = c("Intervention", "Control"
    ), class = "factor")), .Names = c("id", "doe", "dlw", "dfi", 
"gtol", "grp"), row.names = as.integer(c(NA, 1519)), class = "data.frame")
